@@ -30,9 +30,8 @@ class SSIActivateTask : public Task
 public:
 	SSIActivateTask( Task* parent );
 	~SSIActivateTask();
-	void onGo();
+	void onGo() Q_DECL_OVERRIDE;
 };
 
 #endif
 
-// kate: tab-width 4; indent-mode csands;
